from legal_doc_processing import logger

from legal_doc_processing.legal_doc.information_extraction.compliance_obligations import (
    predict_compliance_obligations,
)

from legal_doc_processing.legal_doc.information_extraction.court import (
    predict_court,
)

from legal_doc_processing.legal_doc.information_extraction.judge import (
    predict_judge,
)

from legal_doc_processing.legal_doc.information_extraction.cooperation_credit import (
    predict_cooperation_credit,
)

from legal_doc_processing.legal_doc.information_extraction.code_law_violation import (
    predict_code_law_violation,
)
from legal_doc_processing.legal_doc.information_extraction.country_of_violation import (
    predict_country_of_violation,
)
from legal_doc_processing.legal_doc.information_extraction.currency import (
    predict_currency,
)
from legal_doc_processing.legal_doc.information_extraction.decision_date import (
    predict_decision_date,
)
from legal_doc_processing.legal_doc.information_extraction.defendant import (
    predict_defendant,
)
from legal_doc_processing.legal_doc.information_extraction.extracted_authorities import (
    predict_extracted_authorities,
)

from legal_doc_processing.legal_doc.information_extraction.extracted_sanctions import (
    predict_extracted_sanctions,
)
from legal_doc_processing.legal_doc.information_extraction.extracted_violations import (
    predict_extracted_violations,
)
from legal_doc_processing.legal_doc.information_extraction.folder import predict_folder

# from legal_doc_processing.legal_doc.information_extraction.juridiction import (
#     predict_juridiction,
# )

from legal_doc_processing.legal_doc.information_extraction.justice_type import (
    predict_justice_type,
)

from legal_doc_processing.legal_doc.information_extraction.monitor import (
    predict_monitor,
)
from legal_doc_processing.legal_doc.information_extraction.monetary_sanction import (
    predict_monetary_sanction,
)

from legal_doc_processing.legal_doc.information_extraction.nature_de_sanction import (
    predict_nature_de_sanction,
)

from legal_doc_processing.legal_doc.information_extraction.nature_of_violations import (
    predict_nature_of_violations,
)
from legal_doc_processing.legal_doc.information_extraction.penalty_details import (
    predict_penalty_details,
)

# from legal_doc_processing.legal_doc.information_extraction.plaintiff import (
#     predict_plaintiff,
# )
from legal_doc_processing.legal_doc.information_extraction.reference import (
    predict_reference,
)

# from legal_doc_processing.legal_doc.information_extraction.sentence import (
#     predict_sentence,
# )
from legal_doc_processing.legal_doc.information_extraction.violation_date import (
    predict_violation_date,
)
from legal_doc_processing.legal_doc.information_extraction.type import (
    predict_type,
)
