from legal_doc_processing.press_release.compliance_obligations.predict import (
    predict_compliance_obligations,
)

from legal_doc_processing.press_release.court.predict import (
    predict_court,
)

from legal_doc_processing.press_release.cooperation_credit.predict import (
    predict_cooperation_credit,
)
from legal_doc_processing.press_release.extracted_sanctions.predict import (
    predict_extracted_sanctions,
)

from legal_doc_processing.press_release.country_of_violation.predict import (
    predict_country_of_violation,
)
from legal_doc_processing.press_release.currency.predict import (
    predict_currency,
)

from legal_doc_processing.press_release.decision_date.predict import (
    predict_decision_date,
)

from legal_doc_processing.press_release.defendant.predict import (
    predict_defendant,
)

from legal_doc_processing.press_release.extracted_authorities.predict import (
    predict_extracted_authorities,
)

from legal_doc_processing.press_release.extracted_violations.predict import (
    predict_extracted_violations,
)

from legal_doc_processing.press_release.folder.predict import (
    predict_folder,
)

from legal_doc_processing.press_release.justice_type.predict import (
    predict_justice_type,
)

from legal_doc_processing.press_release.monitor.predict import (
    predict_monitor,
)
from legal_doc_processing.press_release.monetary_sanction.predict import (
    predict_monetary_sanction,
)

from legal_doc_processing.press_release.nature_de_sanction.predict import (
    predict_nature_de_sanction,
)

from legal_doc_processing.press_release.nature_of_violations.predict import (
    predict_nature_of_violations,
)
from legal_doc_processing.press_release.penalty_details.predict import (
    predict_penalty_details,
)

from legal_doc_processing.press_release.reference.predict import (
    predict_reference,
)

from legal_doc_processing.press_release.violation_date.predict import (
    predict_violation_date,
)
from legal_doc_processing.press_release.type.predict import (
    predict_type,
)
from legal_doc_processing.press_release.judge.predict import (
    predict_judge,
)
