# from legal_doc_processing import logger
# from legal_doc_processing.legal_doc.legal_doc import LegalDoc
# from legal_doc_processing.legal_doc.legal_doc import from_file, from_text
# from legal_doc_processing.legal_doc.utils import legal_doc_X_y as load_X_y
